@@ -941,12 +941,15 @@ pyg_type_register(PyObject *self, PyObject *args)
                                     class->tp_name,
                                     name_serial > 1? name_serial_str : NULL,
                                     NULL);
+	    Py_DECREF(module);
         } else {
             if (module)
                 Py_DECREF(module);
             else
                 PyErr_Clear();
-            type_name = g_strdup(class->tp_name);
+            type_name = g_strconcat(class->tp_name,
+                                    name_serial > 1? name_serial_str : NULL,
+                                    NULL);
         }
           /* convert '.' in type name to '+', which isn't banned (grumble) */
         for (i = 0; type_name[i] != '\0'; i++)
@@ -1041,15 +1044,19 @@ pyg_type_register(PyObject *self, PyObject *args)
             GType itype;
             const GInterfaceInfo *iinfo;
             
-            if (PyObject_IsSubclass((PyObject *) base,
-                                    (PyObject *) &PyGInterface_Type) != 1)
+            if (((PyTypeObject *) base)->tp_base != &PyGInterface_Type)
                 continue;
+
             itype = pyg_type_from_object((PyObject *) base);
             iinfo = pyg_lookup_interface_info(itype);
             if (!iinfo) {
-                PyErr_Format(PyExc_NotImplementedError, "Interface type %s "
-                             "has no python implementation support", base->tp_name);
-                return NULL;
+                char *msg;
+                msg = g_strdup_printf("Interface type %s "
+                                      "has no python implementation support",
+                                      base->tp_name);
+                PyErr_Warn(PyExc_RuntimeWarning, msg);
+                g_free(msg);
+                continue;
             }
             g_type_add_interface_static(instance_type, itype, iinfo);
         }
